==> App-GitHooks-Plugin-ValidateChangelogFormat-v1.0.0.tar.gz: App-GitHooks-Plugin-ValidateChangelogFormat-v1.0.0/README.md <==
App-GitHooks-Plugin-ValidateChangelogFormat
===========================================

[![Build Status](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat.svg?branch=master)](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat/badge.svg?branch=master)](https://coveralls.io/r/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat?branch=master)
[![Latest Version](https://img.shields.io/github/tag/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat.svg?style=flat)](https://metacpan.org/release/App-GitHooks-Plugin-ValidateChangelogFormat)

App::GitHooks plugin to validate the format of changelog files.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc App::GitHooks::Plugin::ValidateChangelogFormat


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/App-GitHooks-Plugin-ValidateChangelogFormat)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/App-GitHooks-Plugin-ValidateChangelogFormat)

 * [MetaCPAN]
   (https://metacpan.org/release/App-GitHooks-Plugin-ValidateChangelogFormat)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2015 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> App-GitHooks-Plugin-ValidateChangelogFormat-v1.1.0.tar.gz: App-GitHooks-Plugin-ValidateChangelogFormat-v1.1.0/README.md <==
App-GitHooks-Plugin-ValidateChangelogFormat
===========================================

[![Build Status](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat.svg?branch=master)](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat/badge.svg?branch=master)](https://coveralls.io/r/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat?branch=master)
[![CPAN](https://img.shields.io/cpan/v/App-GitHooks-Plugin-ValidateChangelogFormat.svg)](https://metacpan.org/release/App-GitHooks-Plugin-ValidateChangelogFormat)
[![License](https://img.shields.io/badge/license-Perl%205-blue.svg)](http://dev.perl.org/licenses/)

App::GitHooks plugin to validate the format of changelog files.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc App::GitHooks::Plugin::ValidateChangelogFormat


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/App-GitHooks-Plugin-ValidateChangelogFormat/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/App-GitHooks-Plugin-ValidateChangelogFormat)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/App-GitHooks-Plugin-ValidateChangelogFormat)

 * [MetaCPAN]
   (https://metacpan.org/release/App-GitHooks-Plugin-ValidateChangelogFormat)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2015-2017 Guillaume Aubert.

This code is free software; you can redistribute it and/or modify it under the
same terms as Perl 5 itself.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the LICENSE file for more details.
